<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>RFID名称：</span>
                    <el-input class="input-box" v-model="RFIDData.params.rfidName" placeholder="RFID名称" clearable> </el-input>
                </div>
                <div class="basic-line">
                    <span>RFID编码：</span>
                    <el-input class="input-box" v-model="RFIDData.params.rfid" placeholder="RFID编码" clearable> </el-input>
                </div>
                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增RFID
                </el-button>
            </div>
            <el-table :data="RFIDData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="rfidName" label="RFID名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="rfid" label="RFID编码" show-overflow-tooltip></el-table-column>
                <el-table-column prop="createUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="150">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="Edit" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" :icon="Delete" @click="onDelProductionDevice(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="RFIDData.params.pageIndex" background v-model:page-size="RFIDData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="RFIDData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <RFIDDialog ref="RFIDDialogRef" @refreshRFID="initRFIDTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import RFIDDialog from './components/RFIDDialog.vue';
import { RFIDApi } from '/@/api/intellectInspectSystem/RFID';
import { Edit, View, Plus, Delete, Refresh, Search, Download } from '@element-plus/icons-vue';
import type { UploadProps, UploadUserFile } from 'element-plus'
// 定义接口来定义对象的类型
interface TableData {
    quota: string;
    quotaUnit: string;
    quotaType: string;
    createUserName: string;
    gmtCreate: string;
    lastEditUserName: string;
    gmtModitify: string;
}
interface TableDataState {
    RFIDData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            rfid: number | null;
            rfidName: string | null;
        };
    };
}

export default defineComponent({
    name: 'RFID',
    components: { RFIDDialog, Edit, Delete },
    setup() {
        const RFIDDialogRef = ref();
        const state = reactive<TableDataState>({
            RFIDData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    rfid: null,
                    rfidName: null
                }
            }
        });

        // 初始化表格数据
        const initRFIDTableData = async () => {
            let res = await RFIDApi().getRFIDList(state.RFIDData.params);
            if (res.data.code === '200') {
                state.RFIDData.data = res.data.data.records;
                state.RFIDData.total = res.data.data.total;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            RFIDDialogRef.value.openRFIDDialog(type, value);
        };
        // 删除
        const onDelProductionDevice = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该RFID：“${row.rfidName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await RFIDApi().deleteRFID({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initRFIDTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const handleSearch = () => {
            initRFIDTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.RFIDData.params.pageSize = val;
            initRFIDTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.RFIDData.params.pageIndex = val;
            initRFIDTableData();
        };
        // 页面加载时
        onMounted(() => {
            initRFIDTableData();
        });

        return {
            Edit,
            Delete,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelProductionDevice,
            onHandleCurrentChange,
            RFIDDialog,
            RFIDDialogRef,
            initRFIDTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped>
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
